# pyqt5_designer_mini

[![PyPI - Version](https://img.shields.io/pypi/v/pyqt5-designer-mini.svg)](https://pypi.org/project/pyqt5-designer-mini)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyqt5-designer-mini.svg)](https://pypi.org/project/pyqt5-designer-mini)

-----

**Table of Contents**

- [Introduction](#introduction)
- [Installation](#installation)
- [License](#license)



## Introduction 

This package is designed for two reasons :
1- Remove the necessity of installing pyqt5_tools packages to be able to use designer , ignoring some problems in pip versioning (on windows)
2- Providing a minimalist package to run Qt5 Designer( less than 1MB ) that relies on existing pyqt5 bin files 


## Installation

```console
pip install pyqt5-designer-mini
```

## License

`pyqt5-designer-mini` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
